class Dimension:
    """ tuple(size) """
    _compress_size = None

    def __init__(self, size):
        if isinstance(size, int):
            self.width = size
            self.height = 0
        else:
            self.width = size[0]
            self.height = size[1] if len(tuple(size)) == 2 else 0

    @property
    def width(self):
        return self._width

    @width.setter
    def width(self, value):
        self._width = value

    @property
    def height(self):
        return self._height

    @height.setter
    def height(self, value):
        self._height = value

    # compress size
    @property
    def compress_size(self):
        return self._compress_size

    @compress_size.setter
    def compress_size(self, value):
        self._compress_size = value

    def set_compress_size(self, image):
        print("c:{},i:{}".format(self.width, image.size[0]))
        width_percent = (
                self.width / float(image.size[0])
        )
        height_size = int(
            (float(image.size[1]) * float(width_percent))
        )
        self.compress_size = tuple((width_percent, height_size))



import sys

from PIL import Image
import os
import uuid

from django.core.files.uploadedfile import InMemoryUploadedFile


class ImageFile:
    _name = None

    def __init__(self, image):
        # set image
        self.image = Image.open(image).convert('RGB')
        # set extension image
        self.extension = os.path.splitext(image.name)[1]

    """ image """

    @property
    def image(self):
        return self._image

    @image.setter
    def image(self, value):
        self._image = value

    """ extension """

    @property
    def extension(self):
        return self._extension

    @extension.setter
    def extension(self, value):
        self._extension = value

    """ set image name"""

    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value

    def set_name(self, name):
        if not name:
            self.name = "{}{}".format(uuid.uuid4().hex[:8].upper(), self.extension)
        else:
            self.name = "{}{}".format(name, self.extension)

    def save_file(self, name, output):
        self.set_name(name)
        img = InMemoryUploadedFile(
            output, 'ImageField', "{}".format(
                self.name
            ), 'image/jpeg', sys.getsizeof(output), None
        )
        return img



from PIL import Image
from io import BytesIO

from django_image_compress.dimension import Dimension
from django_image_compress.image_file import ImageFile


class Compress:
    image_file = None
    dimension = None
    output = None

    def auto_resize(self):
        self.image_file.image = self.image_file.image.resize(
            (self.dimension.width, self.dimension.compress_size[1]),
            Image.ANTIALIAS
        )
        print('auto')

    def fixed_resize(self):
        self.image_file.image = self.image_file.image.resize(
            (
                int(self.dimension.width),
                int(self.dimension.height)
            ),
            Image.ANTIALIAS
        )
        print('not auto')

    def resize(self, image, size, name=None):
        # set image
        self.image_file = ImageFile(image)
        self.output = BytesIO()
        # set dimension image
        self.dimension = Dimension(size)
        self.dimension.set_compress_size(self.image_file.image)
        # fixed resolution
        if self.dimension.height:
            if self.dimension.height == 0:
                self.auto_resize()
            else:
                self.fixed_resize()
        else:
            self.auto_resize()
        # save and return image
        self.image_file.image.save(self.output, format='JPEG', quality=100)
        self.output.seek(0)
        return self.image_file.save_file(name, self.output)


compress = Compress()
